%- Example script for providing inputs to keff_SIZ.m for calculating
%- the gas transfer velocity in m/d from shear and buoyancy driven
%- turbulence in the Ice-Ocean Boundary Layer.
%
% AUTHOR:  Brice Loose (osoberlice@gmail.com)
%          Arash Bigdeli (arash.big@gmail.com)
%
% REFERENCE:
%       Loose et al., (2013), "A parameter model of gas exchange for the 
%       seasonal sea ice zone", Ocean S78890ci. Discuss., 10(4), 1169-1204.
%
% DISCLAIMER:
%    This software is provided "as is" without warranty of any kind.  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


%% example 1 
clc;clear,close all;fig1 = figure;

%This example shows the relation of sea ice cover and speed vs gas exchange
Uwind = [5 10 15];     %Wind speed in m/s
Uice = 0.02.*Uwind; % free drift 0.02*Uwind
waterT = 0;  %Water Temp in deg C - 1.5
airT   = 5;  %Air Temp in deg C 1
sic = 1:1:100;  %Sea ice Concentration in %.

for i = 1:length(Uwind)
[keff_i(:,i)] = keff_SIZ(Uice(i),Uwind(i),sic,waterT,airT);
[keff(:,i)] = keff_SIZ(0,Uwind(i),sic,waterT,airT);
end

%Plotting
ax1 = plot(sic,keff_i,'linewidth',2);hold on;
ax2 = plot(sic,keff,'--','linewidth',2);
ax3=plot(sic,keff,'k','linewidth',2,'visible','off');
ax4=plot(sic,keff_i,'k--','linewidth',2,'visible','off');

ylabel('k_{eff} (m/d)');  xlabel('SI cover %');
title('Gas exchange vs SI cover')
legend([ax3(1) ax4(1) ax1'],'Free drift SI','Stationary SI',...
    'Uwind 5ms^{-1}','Uwind 10ms^{-1}','Uwind 15ms^{-1}'...
    ,2,'location','northeast') 

%% example 2
clc;clear;fig2 = figure;

%This example shows the relation of sea ice cover and speed vs gas exchange
Uwind = [5 10 15];     %Wind speed in m/s
Uice = 0.*Uwind; % stationary SI
waterT = 0;  %Water Temp in deg C - 1.5
airT   = 5;  %Air Temp in deg C 1
sic = 1:1:100;  %Sea ice Concentration in %.

%-Quadratic fomulation by Wannikoff (1999) and Model output
for i = 1:length(Uwind)
[keff_i(:,i)] = keff_SIZ(Uice(i),Uwind(i),sic,waterT,airT);
k_quad(:,i) = (0.251.*Uwind(i).^2).*(1-sic./100).*0.24;
end

%Plotting
ax1 = plot(sic,keff_i,'linewidth',2);hold on;
ax2=plot(sic,k_quad,'--','linewidth',2);
ax3=plot(sic,keff_i,'k','linewidth',2,'visible','off');
ax4=plot(sic,k_quad,'k--','linewidth',2,'visible','off');
ylabel('k_{eff} (m/d)');  xlabel('SI cover %');
title('Gas exchange vs SI cover')
legend([ax3(1) ax4(1) ax1'],'Model with Stationary SI',...
    'Quadratic = 0.24*0.251 U_{10}^2 f_{open}',...
    'Uwind 5ms^{-1}','Uwind 10ms^{-1}','Uwind 15ms^{-1}',2,'location','northeast')

